@@ -177,10 +177,12 @@ class SME_Structure(Parameters):
             "float: minimum accuracy for linear spectrum interpolation vs. wavelength."),
         ("accrt", 1e-4, asfloat, this,
             "float: minimum accuracy for synthethized spectrum at wavelength grid points in sme.wint."),
-        ("accxt", 1e-4, asfloat, this,
+        ("accxt", 1e-6, asfloat, this,
             "float: minimum accuracy of the parameters in the fitting procedure"),
-        ("accft", 1e-4, asfloat, this,
+        ("accft", 1e-3, asfloat, this,
             "float: minimum accuracy of the best fit cost"),
+        ("accgt", 1e-4, asfloat, this,
+            "float: minimum accuracy of the gradient of the least squares fit"),
         ("iptype", None, lowercase(oneof(None, "gauss", "sinc", "table")), this, "str: instrumental broadening type"),
         ("ipres", 0, array(None, float), this, "float, array: Instrumental resolution for instrumental broadening"),
         ("ip_x", None, this, this, "array: Instrumental broadening table in x direction"),
